California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 034 - RESTRICTS SPENDING BY HEALTH CARE PROVIDERS MEETING SPECIFIED CRITERIA. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1462796 | YES ON 34, PROTECT PATIENTS NOW: A COALITION OF WOMEN, VETERANS, LGBTQ+ ADVOCATES, AND PATIENT GROUPS, SPONSORED BY CALIFORNIA APARTMENT ASSOCIATION | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1469081 | STOP THE REVENGE INITIATIVE - NO ON 34, SPONSORED BY AIDS HEALTHCARE FOUNDATION | OPPOSE